@@ -15,6 +15,11 @@ class NullUndefined(jinja2.Undefined):
     def __unicode__(self):
         return unicode(self._undefined_name)
 
+    def __getattr__(self, name):
+        return unicode('{}.{}'.format(self, name))
+
+    def __getitem__(self, name):
+        return '{}["{}"]'.format(self, name)
 
 def get_section(parent, name, lints):
     section = parent.get(name, {})
@@ -94,7 +99,7 @@ def lintify(meta, recipe_dir=None):
     # 8: The build section should be before the run section in requirements.
     requirements_order_sorted = sorted(requirements_section,
                                        key=REQUIREMENTS_ORDER.index)
-    if requirements_section.keys() != requirements_order_sorted:
+    if list(requirements_section.keys()) != requirements_order_sorted:
         lints.append('The `requirements/build` section should be defined '
                      'before the `requirements/run` section.')
 
